@@ -22,9 +22,9 @@ var iter = new Gtk.TreeIter();
 m.append(iter);
 m.set_value(iter, 0, [GObject.TYPE_INT, 3]);
 m.append(iter);
-m.set_value(iter, 0, 2);
+m.set_value(iter, 0, [GObject.TYPE_INT, 2]);
 m.append(iter);
-m.set_value(iter, 0, 9);
+m.set_value(iter, 0, [GObject.TYPE_INT, 9]);
 
 //TODO: FIXME: Why does property not work here?
 v.set_model(m);
