@@ -1,7 +1,7 @@
 #!/usr/bin/env seed
 
-Seed.import_namespace("Gtk");
-Seed.import_namespace("GLib");
+Gtk = imports.gi.Gtk;
+GLib = imports.gi.GLib;
 
 Gtk.init(null, null);
 var w = new Gtk.Window();
