@@ -45,12 +45,8 @@ closure_invalidated (gpointer data, GClosure * c)
   SeedClosure *closure = (SeedClosure *) c;
   
   SEED_NOTE (FINALIZATION, "Finalizing closure.");
-/*
-  WebKit bug?
-	if (!JSValueIsUndefined(ctx, closure->user_data))
-		JSValueUnprotect(ctx, closure->user_data);
-	if (!JSValueIsUndefined(ctx, closure->this))
-	JSValueUnprotect(ctx, closure->this);*/
+  if (closure->user_data && !JSValueIsUndefined(ctx, closure->user_data))
+    JSValueUnprotect(ctx, closure->user_data);
   if (!JSValueIsUndefined (ctx, closure->function))
     JSValueUnprotect (ctx, closure->function);
 
@@ -108,11 +104,9 @@ seed_gobject_signal_connect (JSContextRef ctx,
   if (user_data && !JSValueIsNull (ctx, user_data))
     {
       ((SeedClosure *) closure)->user_data = user_data;
-      //  JSValueProtect(ctx, user_data);
+      JSValueProtect(ctx, user_data);
     }
 
-  JSValueProtect (ctx, (JSObjectRef) func);
-
   g_signal_connect_closure (on_obj, signal_name, closure, FALSE);
 }
 
@@ -162,8 +156,6 @@ seed_add_signals_to_object (JSContextRef ctx,
 			    JSObjectRef object_ref, GObject * obj)
 {
   GType type;
-  GType *interfaces;
-  guint n, i;
   JSObjectRef signals_ref, connect_func;
 
   g_assert (obj);
@@ -391,7 +383,6 @@ seed_signal_holder_get_property (JSContextRef ctx,
 				 JSValueRef *exception)
 {
   GObject *gobj = JSObjectGetPrivate (object);
-  GType type = G_OBJECT_TYPE (gobj);
   signal_privates *priv = g_slice_alloc (sizeof (signal_privates));
   guint length = JSStringGetMaximumUTF8CStringSize (property_name);
   gchar *signal_name = g_malloc (length * sizeof (gchar));
