@@ -19,9 +19,8 @@ class_init: function(klass, prototype)
 													  false,
 													  GObject.ParamFlags.READABLE | GObject.ParamFlags.WRITABLE));
 },
-init: function(klass)
+init: function()
 {
-	
 }};
 
 HelloWindow = new GType(HelloWindowType);
@@ -29,4 +28,4 @@ w = new HelloWindow({test: true});
 Seed.print(w.test);
 w = new HelloWindow();
 Seed.print(w.test);
-	  
+
